Skip to contents

This silently overwrites any existing values in the cache.

Usage

hm_load_cache(file)

Arguments

file

Including the path.

Value

Invisible true

See also

For more details see the cache section in `vignette("Supersonic_Routes_in_depth")`.

Examples

# not run
# hm_load_cache(file="") #load from this file