so that the best route are plotted on top. The fields are:
timestamp: when the leg was originally generated (it may have been cached)
fullRouteID: including the refuel stop if any
routeID: origin and destination airport, in make_AP2 order
refuel_ap: code for the refuelling airport, or NA
acID, acType: aircraft identifiers taken from the aircraft set
M084_h: flight time for a Mach 0.84 comparator aircraft (including 2*arrdep_h)
gcdist_km: great circle distance between the origin and destination airports
sea_time_frac: Fraction of time_h time spent over sea, hence at supersonic speed,
or accelerating to, or decelerating from supersonic speed
sea_dist_frac: as sea_time_frac, but fraction of dist_km
dist_km: total length of the route, in km
time_h: total time, in hours
n_phases: number of distinct phases: arr/dep, transition, land, sea, refuel.
advantage_h: M084_h - time_h
circuity: the route distance extension (1 = perfect) dist_km / gcdist_km
best: for each routeID, the fullrouteID with maximum advantage_h